pub struct DataSlice {
pub off: usize,
pub len: usize,
pub data: Data,
}
Slice of Data to be written to storage.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.