Module rustdb::block

source ·
block::BlockStg - divides Storage into relocatable fixed size blocks, basis for dividedstg::DividedStg.

Structs

  • Manages allocation and deallocation of numbered relocatable fixed size blocks from underlying Storage.

Constants