Module sys

Module sys 

System table functions.

Functions

create_function
Create or alter a function in the database by saving the source into the Function system table.
create_index
Create a new table index by writing to the system Index and IndexColumn tables.
create_schema
Create a schema in the database by writing to the system Schema table.
create_table
Create a new table in the database by writing to the system Table and Column tables.
get_function
Get then parse a function from the database.
get_function_id
Get the id of a function.
get_id_gen
Get the IdGen field for a table. This is only needed to initialise system tables.
get_index
Get information about an index from name.
get_schema
Get the id of a schema from a name.
get_table
Gets table from the database.
save_id_gen
Update IdGen field for a table.
set_ix_root
Update root page for index.
set_root
Update root page for table ( for ALTER TABLE ).