Module table

Module table 

Table, ColInfo, Row and other Table types for direct table access.

Structs

Access
Helper struct to access byte data using ColInfo ( returned by Table::access method ).
ColInfo
Table name, column names/types and other calculated values for a table.
IdScan
State for fetching record with specified id.
Index
Table Index.
IndexInfo
Index information for creating an index.
IndexRow
Row for inserting into an index.
IndexScan
State for fetching records using an index.
Row
Row of Values, with type information.
Table
Database base table. Underlying file, type information about the columns and id allocation.
WriteAccess
Helper class to read/write byte data using ColInfo.

Functions

row_compare
Compare table rows.

Type Aliases

IxList
List of indexes. Each index has a file and a list of column numbers.