pub struct WMap {
pub map: BTreeMap<u64, DataSlice>,
}Expand description
Implements an updateable file based on some underlying storage.
Fields
map: BTreeMap<u64, DataSlice>Map of outstanding writes which have not yet been written to the underlying file.
Implementations