Module rustdb::block

source ·
block::BlockStg - divides Storage into relocatable fixed size blocks, basis for dividedstg::DividedStg.

Structs

  • Manages allocation and deallocation of numbered relocatable fixed size blocks from underlying Storage.

Constants

  • Capacity of block in bytes ( after allowing for number reserved for block number ).
  • Number of bytes for block number, plus an extra bit (for ALLOC_BIT).
  • Reserved area for client.