Page storage and sharing, SharedPagedData and AccessPagedData. Note: several structs and their fields are pub to allow diagnostics but are subject to change.
Structs
- Access to shared paged data.
- Heap Node.
- Heap for tracking least used page.
- Information for a logical page, including historic data.
- Allows logical database pages to be shared to allow concurrent readers.
- Central store of data.
Type Aliases
Arc<Mutex<PageInfo>>