System table functions.
Functions
- create_
function - Create or alter a function in the database by saving the source into the Function system table.
- create_
index - Create a new table index by writing to the system Index and IndexColumn tables.
- create_
schema - Create a schema in the database by writing to the system Schema table.
- create_
table - Create a new table in the database by writing to the system Table and Column tables.
- get_
function - Get then parse a function from the database.
- get_
function_ id - Get the id of a function.
- get_
id_ gen - Get the IdGen field for a table. This is only needed to initialise system tables.
- get_
index - Get information about an index from name.
- get_
schema - Get the id of a schema from a name.
- get_
table - Gets table from the database.
- save_
id_ gen - Update IdGen field for a table.
- set_
ix_ root - Update root page for index.
- set_
root - Update root page for table ( for ALTER TABLE ).