Structs
- Helper struct to access byte data using ColInfo ( returned by Table::access method ).
- Table name, column names/types and other calculated values for a table.
- State for fetching record with specified id.
- Table Index.
- Index information for creating an index.
- Row for inserting into an index.
- State for fetching records using an index.
- Row of Values, with type information.
- Database base table. Underlying file, type information about the columns and id allocation.
- Helper class to read/write byte data using ColInfo.
Enums
- Save or Rollback.
Functions
- Compare table rows.
Type Aliases
- List of indexes. Each index has a file and a list of column numbers.